@@ -139,7 +139,7 @@ class Escrow:
             open(filename,'w+').write('0')
         current = int(open(filename).read().strip())
         current+=money
-        open(filename).write(str(current))
+        open(filename,'w+').write(str(current))
 
     #Get the current amount of revenue
     def getRevenue(self,filename="revenue.txt"):
